ai-katie
========

The utility for Data Science and AI using common libraries.
Extended by myself when I'm running to problem that might happen more than once.

- Github: https://github.com/danpeczek/ai-katie

+-----------------+
|    **main**     |
+=================+
| |Build Status|  |
+-----------------+

Setup
=====
To setup to library you need at least Python 3.8 and pip installed.

Also as the package uses PyTorch I strongly suggest to install the PyTorch
in the distribution of your choice from: https://pytorch.org/get-started/locally/ before installing the library.

When all dependencies are installed you can install the library by:

    $ pip install ai-katie

License
-------

`MIT LICENSE <./LICENSE>`__

.. |Build Status| image:: https://app.travis-ci.com/danpeczek/ai-katie.svg?token=ECqr2qx7PpxzXbk67mZ9&branch=main
